@@ -2,5 +2,5 @@ pub mod json_stream;
 pub mod percent_encoding;
 pub mod serde;
 
-pub use self::percent_encoding::percent_encode;
+pub use self::percent_encoding::{percent_encode, url};
 pub use json_stream::JsonStream;
